@@ -49,6 +49,8 @@ class DnsHelper:
         self._res = dns.resolver.Resolver(configure=configure)
 
         if ns_server:
+            if isinstance(ns_server, str):
+                ns_server = [ns_server]
             self._res.nameservers = ns_server
             if len(ns_server) > 1:
                 self._res.rotate = True
@@ -82,7 +84,7 @@ class DnsHelper:
             return self._res.resolve(addr_, type_, tcp=self._is_tcp)
         except (dns.exception.Timeout, dns.resolver.NXDOMAIN,
                 dns.resolver.YXDOMAIN, dns.resolver.NoAnswer,
-                dns.resolver.NoNameservers, socket.error):
+                dns.resolver.NoNameservers, dns.name.EmptyLabel, socket.error):
             return None
 
     def resolve(self, target, type_, ns=None):
